==> enterprisemodules-easy_type-2.37.0.tar.gz: enterprisemodules-easy_type-2.37.0/lib/easy_type/flexible_fact.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'facter'
module EasyType
  class FlexibleFact

    def self.define(basic_name, &definition)
      obj = new(basic_name)
      obj.instance_eval(&definition)
      obj.apply()
    end

    def self.config_dir
      kernel = Facter.value(:kernel)
      case kernel
      when 'Linux'
        '/etc/puppetlabs/facter'
      when 'windows'
        'C:/ProgramData/PuppetLabs/facter/etc'      
      else
        fail "'#{kernel}' not (yet) supported."
      end
    end
  
    def self.config_file
      "#{config_dir}/facter.conf"
    end
  
    def self.config_data
      @config_data ||= Hocon::ConfigFactory.parse_file(config_file).resolve
    end

    def global_config
      if self.class.config_data.has_path?('global')
        self.class.config_data.get_value('global').unwrapped
      else
        {}
      end
    end
  
    def initialize(basic_name)
      @basic_name = basic_name
      @parts = []
    end

    def no_caching_in_facter_yet?
      Gem::Version.new(Facter.version) < Gem::Version.new('4.1.0')
    end

    def force_dot_enabled?
      return false if no_caching_in_facter_yet?

      global_config.dig('force-dot-resolution')
    end

    def force_dot_implementation
      @parts.each do | part|
        #
        # Ensure correct variable are available as local variables in Facter closure scopes
        #
        name = part.keys.first
        implementation = part[name]
        components = @components
        #
        # Now define the facts in the correct way
        #
        Facter.add("#{@basic_name}.#{name}") do
          setcode do
            components.each_with_object({}) do |dir, data|
              data[dir] = implementation.call(dir)
              data
            end
          end
        end
      end
    end

    def chuncked_implementation
      #
      # Ensure correct variable are available as local variables in Facter closure scopes
      #
      parts = @parts
      components = @components
      Facter.add(@basic_name.to_sym, :type => :aggregate) do
        parts.each do | part|
          name = part.keys.first
          implementation = part[name]
          chunk(name.to_sym) do
            components.reduce({}) do |data, dir|
              data[name.to_sym] = {dir => implementation.call(dir)}
              data
            end
          end
        end
      end
    end

    def components(components)
      @components = components
    end

    def part(name, &implementation)
      @parts << {name => implementation}
    end

    def apply()
      if force_dot_enabled?
        force_dot_implementation
      else
        chuncked_implementation
      end
    end
  end
end

==> enterprisemodules-easy_type-2.40.0.tar.gz: enterprisemodules-easy_type-2.40.0/lib/easy_type/flexible_fact.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'facter'
module EasyType
  class FlexibleFact

    def self.define(basic_name, &definition)
      obj = new(basic_name)
      obj.instance_eval(&definition)
      obj.apply()
    end

    def self.config_dir
      kernel = Facter.value(:kernel)
      case kernel
      when 'Linux'
        '/etc/puppetlabs/facter'
      when 'windows'
        'C:/ProgramData/PuppetLabs/facter/etc'      
      else
        fail "'#{kernel}' not (yet) supported."
      end
    end
  
    def self.config_file
      "#{config_dir}/facter.conf"
    end
  
    def self.config_data
      @config_data ||= Hocon::ConfigFactory.parse_file(config_file).resolve
    end

    def global_config
      if self.class.config_data.has_path?('global')
        self.class.config_data.get_value('global').unwrapped
      else
        {}
      end
    end
  
    def initialize(basic_name)
      @basic_name = basic_name
      @parts = []
    end

    def no_caching_in_facter_yet?
      Gem::Version.new(Facter.version) < Gem::Version.new('4.1.0')
    end

    def force_dot_enabled?
      return false if no_caching_in_facter_yet?

      global_config.dig('force-dot-resolution')
    end

    def force_dot_implementation
      @parts.each do | part|
        #
        # Ensure correct variable are available as local variables in Facter closure scopes
        #
        name = part.keys.first
        implementation = part[name]
        components = @components
        #
        # Now define the facts in the correct way
        #
        Facter.add("#{@basic_name}.#{name}") do
          setcode do
            components.each_with_object({}) do |dir, data|
              data[dir] = implementation.call(dir)
              data
            end
          end
        end
      end
    end

    def chuncked_implementation
      #
      # Ensure correct variable are available as local variables in Facter closure scopes
      #
      parts = @parts
      components = @components
      Facter.add(@basic_name.to_sym, :type => :aggregate) do
        parts.each do | part|
          name = part.keys.first
          implementation = part[name]
          chunk(name.to_sym) do
            components.reduce({name.to_sym => {}}) do |data, dir|
              data[name.to_sym][dir] = implementation.call(dir)
              data
            end
          end
        end
      end
    end

    def components(components)
      @components = components
    end

    def part(name, &implementation)
      @parts << {name => implementation}
    end

    def apply()
      if force_dot_enabled?
        force_dot_implementation
      else
        chuncked_implementation
      end
    end
  end
end
